FinishError<T> class
final
请求失败结束结果
- Inheritance
-
- Object
- FinishResult<
T> - FinishError
Constructors
-
FinishError(SmartError error, SmartResponse<
T> response) -
const
Properties
- error → SmartError
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
response
→ SmartResponse<
T> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited